package VMOMI::GuestInfoAppStateType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
